<h1 align="center">script-languages-package-management</h1>

<p align="center">
This project provides a unified way of installing different packages from sources like coda, apt and PyPi
</p>

<p align="center">

<a href="https://opensource.org/licenses/MIT">
    <img src="https://img.shields.io/pypi/l/script-languages-package-management" alt="License">
</a>
<a href="https://pypi.org/project/script-languages-package-management/">
    <img src="https://img.shields.io/pypi/dm/script-languages-package-management" alt="Downloads">
</a>
<a href="https://pypi.org/project/script-languages-package-management/">
    <img src="https://img.shields.io/pypi/pyversions/script-languages-package-management" alt="Supported Python Versions">
</a>
<a href="https://pypi.org/project/script-languages-package-management/">
    <img src="https://img.shields.io/pypi/v/script-languages-package-management" alt="PyPi Package">
</a>
</p>

## 🚀 Features

## 🔌️ Prerequisites

- [Python](https://www.python.org/) >= 3.10

## 💾 Installation

```shell
pip install exasol-script-languages-package-management
```

## 📚 Documentation

For futher details, checkout the latest [documentation](https://exasol.github.io/script-languages-package-management/).
